@@ -360,10 +360,37 @@ class TopicStats {
             writeSubscriptionMetric(stream, "pulsar_subscription_filter_rescheduled_msg_count",
                     subsStats.filterRescheduledMsgCount, cluster, namespace, topic, sub,
                     splitTopicAndPartitionIndexLabel);
-            writeSubscriptionMetric(stream, "pulsar_delayed_message_index_size_bytes",
+            writeSubscriptionMetric(stream, "pulsar_subscription_delayed_message_index_size_bytes",
                     subsStats.delayedMessageIndexSizeInBytes, cluster, namespace, topic, sub,
                     splitTopicAndPartitionIndexLabel);
 
+            // write dispatch throttling metrics with `reason` labels to identify specific throttling
+            // causes: by subscription limit, by topic limit, or by broker limit.
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_msg_events",
+                    subsStats.dispatchThrottledMsgEventsBySubscriptionLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "subscription");
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_bytes_events",
+                    subsStats.dispatchThrottledBytesEventsBySubscriptionLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "subscription");
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_msg_events",
+                    subsStats.dispatchThrottledMsgEventsByTopicLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "topic");
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_bytes_events",
+                    subsStats.dispatchThrottledBytesEventsByTopicLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "topic");
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_msg_events",
+                    subsStats.dispatchThrottledMsgEventsByBrokerLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "broker");
+            writeTopicMetric(stream, "pulsar_subscription_dispatch_throttled_bytes_events",
+                    subsStats.dispatchThrottledBytesEventsByBrokerLimit, cluster, namespace, topic,
+                    splitTopicAndPartitionIndexLabel, "subscription", sub,
+                    "reason", "broker");
+
             final String[] subscriptionLabel = {"subscription", sub};
             for (TopicMetricBean topicMetricBean : subsStats.bucketDelayedIndexStats.values()) {
                 String[] labelsAndValues = ArrayUtils.addAll(subscriptionLabel, topicMetricBean.labelsAndValues);
