@@ -127,11 +127,6 @@ public interface TransactionBuffer {
      */
     CompletableFuture<Void> clearSnapshot();
 
-    /**
-     * Clear up the snapshot of the TransactionBuffer and close it.
-     */
-    CompletableFuture<Void> clearSnapshotAndClose();
-
     /**
      * Close the buffer asynchronously.
      *
