@@ -28,6 +28,13 @@ public interface PendingAckHandleStats {
 
     void close();
 
+    long getCommitSuccessCount();
+    long getCommitFailedCount();
+    long getAbortSuccessCount();
+    long getAbortFailedCount();
+
+    PendingAckHandleAttributes getAttributes();
+
     static PendingAckHandleStats create(String topic, String subName, boolean exposeTopicLevelMetrics) {
         return new PendingAckHandleStatsImpl(topic, subName, exposeTopicLevelMetrics);
     }
