@@ -101,4 +101,19 @@ public interface RawReader {
      * Close the raw reader.
      */
     CompletableFuture<Void> closeAsync();
+
+    /**
+     * Stop requesting new messages from the broker until {@link #resume()} is called. Note that this might cause
+     * {@link #readNextAsync()} to block until {@link #resume()} is called and new messages are pushed by the broker.
+     */
+    default void pause() {
+
+    }
+
+    /**
+     * Resume requesting messages from the broker.
+     */
+    default void resume() {
+
+    }
 }
