@@ -86,7 +86,6 @@ import org.apache.pulsar.common.policies.data.ClusterDataImpl;
 import org.apache.pulsar.common.policies.data.TenantInfoImpl;
 import org.apache.pulsar.common.schema.KeyValue;
 import org.apache.pulsar.common.schema.KeyValueEncodingType;
-import org.apache.pulsar.common.schema.SchemaInfoWithVersion;
 import org.apache.pulsar.common.util.ObjectMapperFactory;
 import org.apache.pulsar.websocket.data.ProducerAcks;
 import org.apache.pulsar.websocket.data.ProducerMessage;
@@ -869,66 +868,4 @@ public class TopicsTest extends MockedPulsarServiceBaseTest {
                 + "kv.encoding.type=SEPARATED, key.schema.type=STRING}) to topic persistent:"
                 + "//my-tenant/my-namespace/my-topic"));
     }
-
-    @Test
-    public void testProduceWithAutoConsumeSchema() throws Exception {
-        String topicName = "persistent://" + testTenant + "/" + testNamespace + "/" + testTopicName;
-        admin.topics().createNonPartitionedTopic(topicName);
-        GenericSchema jsonSchema = GenericJsonSchema.of(JSONSchema.of(SchemaDefinition.builder()
-                .withPojo(PC.class).build()).getSchemaInfo());
-        // use producer to create topic schema
-        Producer producer = pulsarClient.newProducer(jsonSchema).topic(topicName).create();
-        producer.close();
-
-        PC pc = new PC("dell", "alienware", 2021, GPU.AMD,
-                new Seller("WA", "main street", 98004));
-        PC anotherPc = new PC("asus", "rog", 2020, GPU.NVIDIA,
-                new Seller("CA", "back street", 90232));
-
-        @Cleanup
-        Consumer<?> consumer = pulsarClient.newConsumer(Schema.AUTO_CONSUME())
-                .topic(topicName)
-                .subscriptionName("auto-schema-sub")
-                .subscriptionType(SubscriptionType.Exclusive)
-                .subscriptionInitialPosition(SubscriptionInitialPosition.Earliest)
-                .subscribe();
-
-        SchemaInfoWithVersion schemaInfoWithVersion = admin.schemas().getSchemaInfoWithVersion(topicName);
-        AsyncResponse asyncResponse = mock(AsyncResponse.class);
-        ProducerMessages producerMessages = new ProducerMessages();
-        producerMessages.setSchemaVersion(schemaInfoWithVersion.getVersion());
-        String message = "["
-                + "{\"key\":\"my-key\",\"payload\":\""
-                + ObjectMapperFactory.getMapper().writer().writeValueAsString(pc).replace("\"", "\\\"")
-                + "\",\"eventTime\":1603045262772,\"sequenceId\":1},"
-                + "{\"key\":\"my-key\",\"payload\":\""
-                + ObjectMapperFactory.getMapper().writer().writeValueAsString(anotherPc).replace("\"", "\\\"")
-                + "\",\"eventTime\":1603045262772,\"sequenceId\":2}]";
-        producerMessages.setMessages(createMessages(message));
-        topics.produceOnPersistentTopic(asyncResponse, testTenant, testNamespace, testTopicName, false,
-                producerMessages);
-        ArgumentCaptor<Response> responseCaptor = ArgumentCaptor.forClass(Response.class);
-        verify(asyncResponse, timeout(5000).times(1)).resume(responseCaptor.capture());
-        Assert.assertEquals(responseCaptor.getValue().getStatus(), Response.Status.OK.getStatusCode());
-
-        List<PC> expected = Arrays.asList(pc, anotherPc);
-        for (int i = 0; i < 2; i++) {
-            Message<?> msg = consumer.receive(2, TimeUnit.SECONDS);
-            Assert.assertTrue(msg.getValue() instanceof GenericJsonRecord);
-            GenericJsonRecord genericJsonRecord = (GenericJsonRecord) msg.getValue();
-            Assert.assertEquals(genericJsonRecord.getField("brand"), expected.get(i).getBrand());
-            Assert.assertEquals(genericJsonRecord.getField("model"), expected.get(i).getModel());
-            Number year = (Number) genericJsonRecord.getField("year");
-            Assert.assertEquals(year.intValue(), expected.get(i).getYear());
-            Assert.assertEquals(genericJsonRecord.getField("gpu"), expected.get(i).getGpu().name());
-            Object seller = genericJsonRecord.getField("seller");
-            Assert.assertTrue(seller instanceof GenericJsonRecord);
-            GenericJsonRecord sellerGenericJsonRecord = (GenericJsonRecord) seller;
-            Assert.assertEquals(sellerGenericJsonRecord.getField("state"), expected.get(i).getSeller().getState());
-            Assert.assertEquals(sellerGenericJsonRecord.getField("street"), expected.get(i).getSeller().getStreet());
-            Number zipCode = (Number) sellerGenericJsonRecord.getField("zipCode");
-            Assert.assertEquals(zipCode.longValue(), expected.get(i).getSeller().getZipCode());
-        }
-    }
-
 }
