@@ -31,7 +31,6 @@ import static org.testng.Assert.fail;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutionException;
@@ -80,15 +79,12 @@ import org.apache.pulsar.common.policies.data.TransactionInPendingAckStats;
 import org.apache.pulsar.common.policies.data.TransactionMetadata;
 import org.apache.pulsar.common.policies.data.TransactionPendingAckInternalStats;
 import org.apache.pulsar.common.policies.data.TransactionPendingAckStats;
-import org.apache.pulsar.common.stats.AnalyzeSubscriptionBacklogResult;
 import org.apache.pulsar.common.stats.PositionInPendingAckStats;
-import org.apache.pulsar.common.util.FutureUtil;
 import org.apache.pulsar.packages.management.core.MockedPackagesStorageProvider;
 import org.apache.pulsar.transaction.coordinator.TxnMeta;
 import org.apache.pulsar.transaction.coordinator.exceptions.CoordinatorException;
 import org.apache.pulsar.transaction.coordinator.impl.MLTransactionLogImpl;
 import org.apache.pulsar.transaction.coordinator.proto.TxnStatus;
-import org.apache.zookeeper.KeeperException;
 import org.awaitility.Awaitility;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeMethod;
@@ -866,7 +862,6 @@ public class AdminApiTransactionTest extends MockedPulsarServiceBaseTest {
         @Cleanup
         Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING)
                 .subscriptionName(subscriptionName)
-                .enableBatchIndexAcknowledgment(true)
                 .subscriptionType(SubscriptionType.Shared)
                 .isAckReceiptEnabled(true)
                 .topic(topic)
@@ -1056,63 +1051,6 @@ public class AdminApiTransactionTest extends MockedPulsarServiceBaseTest {
         }
     }
 
-    @Test
-    public void testAnalyzeSubscriptionBacklogWithTransactionMarker() throws Exception {
-        initTransaction(1);
-        final String topic = BrokerTestUtil.newUniqueName("persistent://public/default/analyze-subscription-backlog");
-        String transactionSubName = "analyze-subscription-backlog-topic-sub";
-
-        // Init subscription and then close the consumer. If consumer is connected and has available permits,
-        // AbstractBaseDispatcher#filterEntriesForConsumer will auto ack marker messages
-        pulsarClient.newConsumer(Schema.STRING).topic(topic).subscriptionName(transactionSubName).subscribe().close();
-        @Cleanup Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(topic).create();
-
-        int numMessages = 10;
-        List<MessageId> committedMsgIds = new ArrayList<>();
-        for (int i = 0; i < numMessages; i++) {
-            Transaction txn = pulsarClient.newTransaction().build().get();
-            MessageId messageId = producer.newMessage(txn).value("commited-msg" + i).send();
-            committedMsgIds.add(messageId);
-            txn.commit().get();
-        }
-
-        AnalyzeSubscriptionBacklogResult backlogResult =
-                admin.topics().analyzeSubscriptionBacklog(topic, transactionSubName, Optional.empty());
-        assertEquals(backlogResult.getMessages(), numMessages);
-        assertEquals(backlogResult.getMarkerMessages(), numMessages);
-
-        MessageId committedMiddleMsgId = committedMsgIds.get(numMessages / 2);
-        backlogResult =
-                admin.topics().analyzeSubscriptionBacklog(topic, transactionSubName, Optional.of(committedMiddleMsgId));
-        assertEquals(backlogResult.getMessages(), numMessages / 2);
-        assertEquals(backlogResult.getMarkerMessages(), numMessages / 2);
-
-        List<MessageId> abortedMsgIds = new ArrayList<>();
-        for (int i = 0; i < numMessages; i++) {
-            Transaction txn = pulsarClient.newTransaction().build().get();
-            MessageId messageId = producer.newMessage(txn).value("aborted-msg" + i).send();
-            abortedMsgIds.add(messageId);
-            txn.abort().get();
-        }
-        backlogResult = admin.topics().analyzeSubscriptionBacklog(topic, transactionSubName, Optional.empty());
-        assertEquals(backlogResult.getMessages(), numMessages * 2);
-        assertEquals(backlogResult.getMarkerMessages(), numMessages * 2);
-
-        MessageId abortedMiddleMsgId = abortedMsgIds.get(numMessages / 2);
-        backlogResult =
-                admin.topics().analyzeSubscriptionBacklog(topic, transactionSubName, Optional.of(abortedMiddleMsgId));
-        assertEquals(backlogResult.getMessages(), numMessages / 2);
-        assertEquals(backlogResult.getMarkerMessages(), numMessages / 2);
-
-        Transaction txn = pulsarClient.newTransaction().build().get();
-        for (int i = 0; i < numMessages; i++) {
-            producer.newMessage(txn).value("uncommitted-msg-" + i).send();
-        }
-        backlogResult = admin.topics().analyzeSubscriptionBacklog(topic, transactionSubName, Optional.empty());
-        assertEquals(backlogResult.getMessages(), numMessages * 3);
-        assertEquals(backlogResult.getMarkerMessages(), numMessages * 2);
-    }
-
     private static void verifyCoordinatorStats(String state,
                                                long sequenceId, long lowWaterMark) {
         assertEquals(state, "Ready");
@@ -1172,32 +1110,4 @@ public class AdminApiTransactionTest extends MockedPulsarServiceBaseTest {
         assertEquals(persistentTopicStats.ledgers.size(), internalStats.ledgers.size());
         assertEquals(persistentTopicStats.cursors.size(), internalStats.cursors.size());
     }
-
-    @Test
-    public void testRetryDeleteTopicAfterFailedDeleteLedger() throws Exception {
-        // Create a topic.
-        final String tpName = BrokerTestUtil.newUniqueName("persistent://public/default/tp");
-        admin.topics().createNonPartitionedTopic(tpName);
-        Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(tpName).create();
-        producer.send("1");
-        producer.close();
-        // The first deleting should fail, since we injected an error.
-        pulsarTestContext.getMockZooKeeper().failConditional(KeeperException.Code.BADVERSION, (op, path) -> {
-            if ("DELETE".equals(op.toString())
-                    && path.endsWith(TopicName.get(tpName).getPersistenceNamingEncoding())) {
-                return true;
-            }
-            return false;
-        });
-        try {
-            admin.topics().delete(tpName);
-            fail("The deleting should fail because we injected an error");
-        } catch (Throwable ex) {
-            // expected
-            Throwable actEx = FutureUtil.unwrapCompletionException(ex);
-            assertTrue(actEx.getMessage().contains("BadVersionException"));
-        }
-        // The second deleting should succeed.
-        admin.topics().delete(tpName);
-    }
 }
