@@ -85,11 +85,11 @@ import org.testng.annotations.Test;
 @Test(groups = "broker")
 public class LoadBalancerTest {
 
-    public final static String CA_CERT_FILE_PATH =
+    public static final String CA_CERT_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/certs/ca.cert.pem");
-    public final static String BROKER_CERT_FILE_PATH =
+    public static final String BROKER_CERT_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/server-keys/broker.cert.pem");
-    public final static String BROKER_KEY_FILE_PATH =
+    public static final String BROKER_KEY_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/server-keys/broker.key-pk8.pem");
 
     LocalBookkeeperEnsemble bkEnsemble;
@@ -133,7 +133,7 @@ public class LoadBalancerTest {
             config.setLoadBalancerOverrideBrokerNicSpeedGbps(Optional.of(1.0d));
             config.setBrokerServicePort(Optional.of(0));
             config.setLoadManagerClassName(SimpleLoadManagerImpl.class.getName());
-            config.setAdvertisedAddress(localhost+i);
+            config.setAdvertisedAddress(localhost + i);
             config.setLoadBalancerEnabled(false);
             config.setTlsTrustCertsFilePath(CA_CERT_FILE_PATH);
             config.setTlsCertificateFilePath(BROKER_CERT_FILE_PATH);
@@ -209,14 +209,16 @@ public class LoadBalancerTest {
             assertTrue(loadReportData.length > 0);
             log.info("LoadReport {}, {}", lookupAddresses[i], new String(loadReportData));
 
-            LoadReport loadReport = ObjectMapperFactory.getMapper().reader().readValue(loadReportData, LoadReport.class);
+            LoadReport loadReport = ObjectMapperFactory.getMapper().reader().readValue(loadReportData,
+                    LoadReport.class);
             assertEquals(loadReport.getName(), lookupAddresses[i]);
 
             // Check Initial Ranking is populated in both the brokers
             Field ranking = ((SimpleLoadManagerImpl) pulsarServices[i].getLoadManager().get()).getClass()
                     .getDeclaredField("sortedRankings");
             ranking.setAccessible(true);
-            AtomicReference<Map<Long, Set<ResourceUnit>>> sortedRanking = (AtomicReference<Map<Long, Set<ResourceUnit>>>) ranking
+            AtomicReference<Map<Long, Set<ResourceUnit>>> sortedRanking =
+                    (AtomicReference<Map<Long, Set<ResourceUnit>>>) ranking
                     .get(pulsarServices[i].getLoadManager().get());
             printSortedRanking(sortedRanking);
 
@@ -297,7 +299,8 @@ public class LoadBalancerTest {
                 .getDeclaredField("sortedRankings");
         ranking.setAccessible(true);
         @SuppressWarnings("unchecked")
-        AtomicReference<Map<Long, Set<ResourceUnit>>> sortedRanking = (AtomicReference<Map<Long, Set<ResourceUnit>>>) ranking
+        AtomicReference<Map<Long, Set<ResourceUnit>>> sortedRanking =
+                (AtomicReference<Map<Long, Set<ResourceUnit>>>) ranking
                 .get(pulsar.getLoadManager().get());
         return sortedRanking;
     }
@@ -440,8 +443,8 @@ public class LoadBalancerTest {
         Field quotasField = ((SimpleLoadManagerImpl) pulsar.getLoadManager().get()).getClass()
                 .getDeclaredField("realtimeResourceQuotas");
         quotasField.setAccessible(true);
-        AtomicReference<Map<String, ResourceQuota>> realtimeResourceQuotas = (AtomicReference<Map<String, ResourceQuota>>) quotasField
-                .get(pulsar.getLoadManager().get());
+        AtomicReference<Map<String, ResourceQuota>> realtimeResourceQuotas =
+                (AtomicReference<Map<String, ResourceQuota>>) quotasField.get(pulsar.getLoadManager().get());
         return realtimeResourceQuotas;
     }
 
@@ -562,7 +565,7 @@ public class LoadBalancerTest {
         Long maxVal = ((long) 1) << 32;
         Long segSize = maxVal / numBundles;
         List<String> partitions = new ArrayList<>();
-        partitions.add(String.format("0x%08x", 0l));
+        partitions.add(String.format("0x%08x", 0L));
         Long curPartition = segSize;
         for (int i = 0; i < numBundles; i++) {
             if (i != numBundles - 1) {
@@ -586,7 +589,7 @@ public class LoadBalancerTest {
     }
 
     /**
-     * Test the namespace bundle auto-split
+     * Test the namespace bundle auto-split.
      */
     @Test
     public void testNamespaceBundleAutoSplit() throws Exception {
@@ -594,7 +597,8 @@ public class LoadBalancerTest {
         long maxTopics = pulsarServices[0].getConfiguration().getLoadBalancerNamespaceBundleMaxTopics();
         int maxSessions = pulsarServices[0].getConfiguration().getLoadBalancerNamespaceBundleMaxSessions();
         long maxMsgRate = pulsarServices[0].getConfiguration().getLoadBalancerNamespaceBundleMaxMsgRate();
-        long maxBandwidth = pulsarServices[0].getConfiguration().getLoadBalancerNamespaceBundleMaxBandwidthMbytes() * 1048576L;
+        long maxBandwidth = pulsarServices[0].getConfiguration()
+                .getLoadBalancerNamespaceBundleMaxBandwidthMbytes() * 1048576L;
         pulsarServices[0].getConfiguration().setLoadBalancerAutoBundleSplitEnabled(true);
 
         // create namespaces
@@ -649,7 +653,8 @@ public class LoadBalancerTest {
         Thread.sleep(5000);
         pulsarServices[0].getLoadManager().get().doNamespaceBundleSplit();
 
-        boolean isAutoUnooadSplitBundleEnabled = pulsarServices[0].getConfiguration().isLoadBalancerAutoUnloadSplitBundlesEnabled();
+        boolean isAutoUnooadSplitBundleEnabled = pulsarServices[0].getConfiguration()
+                .isLoadBalancerAutoUnloadSplitBundlesEnabled();
         // verify bundles are split
         verify(namespaceAdmin, times(1)).splitNamespaceBundle("pulsar/use/primary-ns-01", "0x00000000_0x80000000",
                 isAutoUnooadSplitBundleEnabled, null);
@@ -704,7 +709,8 @@ public class LoadBalancerTest {
             // Make sure all brokers see the same leader
             log.info("Old leader is : {}", oldLeader.getBrokerId());
             for (PulsarService pulsar : activePulsar) {
-                log.info("Current leader for {} is : {}", pulsar.getWebServiceAddress(), pulsar.getLeaderElectionService().getCurrentLeader());
+                log.info("Current leader for {} is : {}", pulsar.getWebServiceAddress(),
+                        pulsar.getLeaderElectionService().getCurrentLeader());
                 assertEquals(pulsar.getLeaderElectionService().readCurrentLeader().join(), Optional.of(oldLeader));
             }
 
@@ -789,14 +795,14 @@ public class LoadBalancerTest {
 
     private PulsarResourceDescription createResourceDescription(long memoryInMB, long cpuPercentage,
             long bandwidthInMbps, long bandwidthOutInMbps, long threads) {
-        long KB = 1024;
-        long MB = 1024 * KB;
-        long GB = 1024 * MB;
+        long kB = 1024;
+        long mB = 1024 * kB;
+        long gB = 1024 * mB;
         PulsarResourceDescription rd = new PulsarResourceDescription();
-        rd.put("memory", new ResourceUsage(memoryInMB, 4 * GB));
+        rd.put("memory", new ResourceUsage(memoryInMB, 4 * gB));
         rd.put("cpu", new ResourceUsage(cpuPercentage, 100));
-        rd.put("bandwidthIn", new ResourceUsage(bandwidthInMbps * MB, GB));
-        rd.put("bandwidthOut", new ResourceUsage(bandwidthOutInMbps * MB, GB));
+        rd.put("bandwidthIn", new ResourceUsage(bandwidthInMbps * mB, gB));
+        rd.put("bandwidthOut", new ResourceUsage(bandwidthOutInMbps * mB, gB));
         return rd;
     }
 
