@@ -37,9 +37,7 @@ import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
 @Slf4j
-// TODO: This test is in flaky group until CI is fixed.
-// To be addressed as part of https://github.com/apache/pulsar/pull/24154
-@Test(groups = "flaky")
+@Test(groups = "broker")
 public class BrokerServiceChaosTest extends CanReconnectZKClientPulsarServiceBaseTest {
 
     @Override
