@@ -26,7 +26,7 @@ import org.testng.annotations.Test;
 /**
  * Tests replicated subscriptions with transaction (PIP-33).
  */
-@Test(groups = "broker")
+@Test(groups = "broker-replication")
 public class ReplicatedSubscriptionWithTransactionTest extends ReplicatedSubscriptionTest {
 
     @Override
