@@ -50,7 +50,7 @@ import org.testng.annotations.Test;
  * a lot of topic deletion and makes namespace policies being incorrect.
  */
 @Slf4j
-@Test(groups = "broker-impl")
+@Test(groups = "broker-replication")
 public class ReplicatorGlobalNSTest extends ReplicatorTestBase {
 
     protected String methodName;
