@@ -39,7 +39,7 @@ import org.testng.annotations.Test;
 /**
  * Starts 3 brokers that are in 3 different clusters.
  */
-@Test(groups = "broker")
+@Test(groups = "broker-replication")
 public class ReplicatorRemoveClusterTest extends ReplicatorTestBase {
 
     protected String methodName;
