@@ -73,6 +73,37 @@ public class TopicPublishRateThrottleTest extends BrokerTestBase{
         pulsarClient.close();
     }
 
+    @Test
+    public void testResumeEvenProducerClosed() throws Exception {
+        PublishRate publishRate = new PublishRate(1, 10);
+        conf.setMaxPendingPublishRequestsPerConnection(0);
+        super.baseSetup();
+        admin.namespaces().setPublishRate("prop/ns-abc", publishRate);
+        final String topic = BrokerTestUtil.newUniqueName("persistent://prop/ns-abc/tp");
+        org.apache.pulsar.client.api.Producer<byte[]> producer = pulsarClient.newProducer()
+                .topic(topic).create();
+
+        Topic topicRef = pulsar.getBrokerService().getTopicReference(topic).get();
+        Assert.assertNotNull(topicRef);
+        MessageId messageId = null;
+        // first will be success, and the second will fail, will set auto read to false.
+        messageId = producer.sendAsync(new byte[10]).get(500, TimeUnit.MILLISECONDS);
+        Assert.assertNotNull(messageId);
+        // second will be blocked
+        producer.sendAsync(new byte[10]);
+
+        // Verify: even through the producer was closed before the unblock, the state should be unblocked at the next
+        // period of rate limiter.
+        producer.close();
+        Thread.sleep(3000);
+        org.apache.pulsar.client.api.Producer<byte[]> producer2 = pulsarClient.newProducer()
+                .topic(topic).create();
+        producer2.sendAsync(new byte[2]).get(500, TimeUnit.MILLISECONDS);
+
+        // Close the PulsarClient gracefully to avoid ByteBuf leak
+        pulsarClient.close();
+    }
+
     @Test
     public void testSystemTopicPublishNonBlock() throws Exception {
         super.baseSetup();
