@@ -26,6 +26,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.mledger.Position;
+import org.apache.bookkeeper.mledger.impl.ActiveManagedCursorContainer;
 import org.apache.bookkeeper.mledger.impl.ManagedCursorContainer;
 import org.apache.bookkeeper.mledger.impl.ManagedCursorImpl;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl;
@@ -573,7 +574,7 @@ public class SubscriptionPauseOnAckStatPersistTest extends ProducerConsumerBase
             return invocation.callRealMethod();
         }).when(spyCursor).isCursorDataFullyPersistable();
         final ManagedCursorContainer cursors = WhiteboxImpl.getInternalState(ml, "cursors");
-        final ManagedCursorContainer activeCursors = WhiteboxImpl.getInternalState(ml, "activeCursors");
+        final ActiveManagedCursorContainer activeCursors = WhiteboxImpl.getInternalState(ml, "activeCursors");
         cursors.removeCursor(cursor.getName());
         activeCursors.removeCursor(cursor.getName());
         cursors.add(spyCursor, null);
