@@ -49,7 +49,7 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
 
     /**
      * verifies that messages whose size is larger than 2^14 bytes (max size of single TLS chunk) can be
-     * produced/consumed
+     * produced/consumed.
      *
      * @throws Exception
      */
@@ -57,8 +57,8 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
     public void testTlsLargeSizeMessage() throws Exception {
         log.info("-- Starting {} test --", methodName);
 
-        final int MESSAGE_SIZE = 16 * 1024 + 1;
-        log.info("-- message size -- {}", MESSAGE_SIZE);
+        final int messageSize = 16 * 1024 + 1;
+        log.info("-- message size -- {}", messageSize);
 
         internalSetUpForClient(true, pulsar.getBrokerServiceUrlTls());
         internalSetUpForNamespace();
@@ -69,7 +69,7 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
         Producer<byte[]> producer = pulsarClient.newProducer().topic("persistent://my-property/use/my-ns/my-topic1")
                 .create();
         for (int i = 0; i < 10; i++) {
-            byte[] message = new byte[MESSAGE_SIZE];
+            byte[] message = new byte[messageSize];
             Arrays.fill(message, (byte) i);
             producer.send(message);
         }
@@ -77,7 +77,7 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
         Message<byte[]> msg = null;
         for (int i = 0; i < 10; i++) {
             msg = consumer.receive(5, TimeUnit.SECONDS);
-            byte[] expected = new byte[MESSAGE_SIZE];
+            byte[] expected = new byte[messageSize];
             Arrays.fill(expected, (byte) i);
             Assert.assertEquals(expected, msg.getData());
         }
@@ -91,8 +91,8 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
     public void testTlsClientAuthOverBinaryProtocol() throws Exception {
         log.info("-- Starting {} test --", methodName);
 
-        final int MESSAGE_SIZE = 16 * 1024 + 1;
-        log.info("-- message size -- {}", MESSAGE_SIZE);
+        final int messageSize = 16 * 1024 + 1;
+        log.info("-- message size -- {}", messageSize);
         internalSetUpForNamespace();
 
         // Test 1 - Using TLS on binary protocol without sending certs - expect failure
@@ -119,8 +119,8 @@ public class TlsProducerConsumerTest extends TlsProducerConsumerBase {
     public void testTlsClientAuthOverHTTPProtocol() throws Exception {
         log.info("-- Starting {} test --", methodName);
 
-        final int MESSAGE_SIZE = 16 * 1024 + 1;
-        log.info("-- message size -- {}", MESSAGE_SIZE);
+        final int messageSize = 16 * 1024 + 1;
+        log.info("-- message size -- {}", messageSize);
         internalSetUpForNamespace();
 
         // Test 1 - Using TLS on https without sending certs - expect failure
