@@ -260,7 +260,7 @@ public class ClientCnxTest extends MockedPulsarServiceBaseTest {
             field.set(clientCnxFuture.get(), false);
         }
         try {
-            clientWitBinaryLookup.getPartitionsForTopic(topic, false).join();
+            clientWitBinaryLookup.getPartitionedTopicMetadata(topic, false, false).join();
             Assert.fail("Expected an error that the broker version is too old.");
         } catch (Exception ex) {
             Assert.assertTrue(ex.getMessage().contains("without auto-creation is not supported by the broker"));
