@@ -20,12 +20,11 @@ package org.apache.pulsar.client.impl;
 
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertTrue;
-
-import lombok.Cleanup;
-import lombok.extern.slf4j.Slf4j;
 import java.lang.reflect.Field;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
+import lombok.Cleanup;
+import lombok.extern.slf4j.Slf4j;
 import org.apache.pulsar.broker.BrokerTestUtil;
 import org.apache.pulsar.client.api.MessageRoutingMode;
 import org.apache.pulsar.client.api.ProducerAccessMode;
@@ -59,7 +58,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         admin.topics().createPartitionedTopic(topic, 10);
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImpl = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImpl =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -78,7 +78,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         admin.topics().createPartitionedTopic(topic, 10);
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImpl = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImpl =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -99,7 +100,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         admin.topics().createPartitionedTopic(topic, 10);
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImpl = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImpl =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -130,7 +132,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         admin.topics().createPartitionedTopic(topic, 10);
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImplExclusive = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImplExclusive =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -144,7 +147,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         producerImplExclusive.close();
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImplWaitForExclusive = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImplWaitForExclusive =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -164,7 +168,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         final Field field = PartitionedProducerImpl.class.getDeclaredField("topicMetadata");
         field.setAccessible(true);
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImpl = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImpl =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -215,7 +220,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         final Field field = PartitionedProducerImpl.class.getDeclaredField("topicMetadata");
         field.setAccessible(true);
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImplExclusive = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImplExclusive =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
@@ -235,7 +241,8 @@ public class PartialPartitionedProducerTest extends ProducerConsumerBase {
         producerImplExclusive.close();
 
         @Cleanup
-        final PartitionedProducerImpl<byte[]> producerImplWaitForExclusive = (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
+        final PartitionedProducerImpl<byte[]> producerImplWaitForExclusive =
+                (PartitionedProducerImpl<byte[]>) pulsarClient.newProducer()
                 .topic(topic)
                 .enableLazyStartPartitionedProducers(true)
                 .enableBatching(false)
