@@ -99,7 +99,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
     private static final int waitTimeForCannotReceiveMsgInSec = 5;
     @BeforeClass(alwaysRun = true)
     protected void setup() throws Exception {
-        conf.setAcknowledgmentAtBatchIndexLevelEnabled(true);
         setUpBase(1, NUM_PARTITIONS, TOPIC_OUTPUT, TOPIC_PARTITION);
         admin.topics().createPartitionedTopic(TOPIC_MESSAGE_ACK_TEST, 1);
     }
@@ -139,7 +138,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .isAckReceiptEnabled(true)
                 .subscriptionName("test")
                 .subscriptionType(SubscriptionType.Shared)
-                .enableBatchIndexAcknowledgment(true)
                 .subscribe();
 
         for (int i = 0; i < count; i++) {
@@ -206,7 +204,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .isAckReceiptEnabled(true)
                 .subscriptionName("test")
                 .subscriptionType(SubscriptionType.Shared)
-                .enableBatchIndexAcknowledgment(true)
                 .subscribe();
 
         for (int i = 0; i < count; i++) {
@@ -238,7 +235,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .isAckReceiptEnabled(true)
                 .subscriptionName("test")
                 .subscriptionType(SubscriptionType.Shared)
-                .enableBatchIndexAcknowledgment(true)
                 .subscribe();
 
         Message<Integer> message = consumer.receive(waitTimeForCannotReceiveMsgInSec, TimeUnit.SECONDS);
@@ -321,7 +317,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .newConsumer()
                 .topic(TOPIC_OUTPUT)
                 .subscriptionName("test")
-                .enableBatchIndexAcknowledgment(true)
                 .subscribe();
         Awaitility.await().until(consumer::isConnected);
 
@@ -394,7 +389,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .topic(TOPIC_OUTPUT)
                 .subscriptionInitialPosition(SubscriptionInitialPosition.Earliest)
                 .subscriptionName(subName)
-                .enableBatchIndexAcknowledgment(true)
                 .subscribe();
         Awaitility.await().until(consumer::isConnected);
 
@@ -616,7 +610,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         Consumer<byte[]> consumer = pulsarClient.newConsumer()
                 .topic(normalTopic)
                 .subscriptionName("test")
-                .enableBatchIndexAcknowledgment(true)
                 .subscriptionType(subscriptionType)
                 .subscribe();
         Awaitility.await().until(consumer::isConnected);
@@ -719,7 +712,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .newConsumer()
                 .topic(topic)
                 .subscriptionName(subName)
-                .enableBatchIndexAcknowledgment(true)
                 .acknowledgmentGroupTime(0, TimeUnit.MILLISECONDS)
                 .subscribe();
         Awaitility.await().until(consumer::isConnected);
@@ -844,7 +836,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
         Consumer<byte[]> consumer = pulsarClient.newConsumer()
                 .topic(normalTopic)
                 .subscriptionName("test")
-                .enableBatchIndexAcknowledgment(true)
                 .subscriptionType(subscriptionType)
                 .ackTimeout(1, TimeUnit.MINUTES)
                 .subscribe();
@@ -1227,7 +1218,6 @@ public class TransactionEndToEndTest extends TransactionTestBase {
                 .newConsumer()
                 .topic(topic)
                 .subscriptionName(subName)
-                .enableBatchIndexAcknowledgment(true)
                 .acknowledgmentGroupTime(0, TimeUnit.MILLISECONDS)
                 .subscribe();
         Awaitility.await().until(consumer::isConnected);
