@@ -91,10 +91,10 @@ public class PulsarFunctionE2ESecurityTest {
     PulsarClient pulsarClient;
     BrokerStats brokerStatsClient;
     PulsarWorkerService functionsWorkerService;
-    final String TENANT = "external-repl-prop";
-    final String TENANT2 = "tenant2";
+    static final String TENANT = "external-repl-prop";
+    static final String TENANT2 = "tenant2";
 
-    final String NAMESPACE = "test-ns";
+    static final String NAMESPACE = "test-ns";
     String pulsarFunctionsNamespace = TENANT + "/pulsar-function-admin";
     String primaryHost;
     String workerId;
@@ -205,7 +205,7 @@ public class PulsarFunctionE2ESecurityTest {
                 .allowedClusters(Collections.singleton("use"))
                 .build();
         superUserAdmin.tenants().createTenant(TENANT2, propAdmin);
-        superUserAdmin.namespaces().createNamespace( TENANT2 + "/" + NAMESPACE);
+        superUserAdmin.namespaces().createNamespace(TENANT2 + "/" + NAMESPACE);
 
         while (!functionsWorkerService.getLeaderService().isLeader()) {
             Thread.sleep(1000);
@@ -216,11 +216,26 @@ public class PulsarFunctionE2ESecurityTest {
     void shutdown() throws Exception {
         try {
             log.info("--- Shutting down ---");
-            pulsarClient.close();
-            superUserAdmin.close();
-            functionsWorkerService.stop();
-            pulsar.close();
-            bkEnsemble.stop();
+            if (pulsarClient != null) {
+                pulsarClient.close();
+                pulsarClient = null;
+            }
+            if (superUserAdmin != null) {
+                superUserAdmin.close();
+                superUserAdmin = null;
+            }
+            if (functionsWorkerService != null) {
+                functionsWorkerService.stop();
+                functionsWorkerService = null;
+            }
+            if (pulsar != null) {
+                pulsar.close();
+                pulsar = null;
+            }
+            if (bkEnsemble != null) {
+                bkEnsemble.stop();
+                bkEnsemble = null;
+            }
         } finally {
             if (tempDirectory != null) {
                 tempDirectory.delete();
@@ -364,7 +379,8 @@ public class PulsarFunctionE2ESecurityTest {
 
             // create a producer that creates a topic at broker
             try (Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(sourceTopic).create();
-                 Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(sinkTopic).subscriptionName("sub").subscribe()) {
+                 Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(sinkTopic)
+                         .subscriptionName("sub").subscribe()) {
 
                 int totalMsgs = 5;
                 for (int i = 0; i < totalMsgs; i++) {
@@ -373,7 +389,8 @@ public class PulsarFunctionE2ESecurityTest {
                 }
                 retryStrategically((test) -> {
                     try {
-                        SubscriptionStats subStats = admin1.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
+                        SubscriptionStats subStats =
+                                admin1.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
                         return subStats.getUnackedMessages() == 0;
                     } catch (PulsarAdminException e) {
                         return false;
@@ -388,8 +405,8 @@ public class PulsarFunctionE2ESecurityTest {
                 // validate pulsar-sink consumer has consumed all messages and delivered to Pulsar sink but unacked
                 // messages
                 // due to publish failure
-                assertNotEquals(admin1.topics().getStats(sourceTopic).getSubscriptions().values().iterator().next().getUnackedMessages(),
-                        totalMsgs);
+                assertNotEquals(admin1.topics().getStats(sourceTopic).getSubscriptions()
+                                .values().iterator().next().getUnackedMessages(), totalMsgs);
 
                 // test update functions
                 functionConfig.setParallelism(2);
@@ -406,7 +423,8 @@ public class PulsarFunctionE2ESecurityTest {
 
                 assertTrue(retryStrategically((test) -> {
                     try {
-                        return admin1.functions().getFunctionStatus(TENANT, NAMESPACE, functionName).getNumRunning() == 2;
+                        return admin1.functions().getFunctionStatus(TENANT, NAMESPACE, functionName).getNumRunning()
+                                == 2;
                     } catch (PulsarAdminException e) {
                         return false;
                     }
@@ -581,7 +599,7 @@ public class PulsarFunctionE2ESecurityTest {
         AuthenticationToken authToken2 = new AuthenticationToken();
         authToken2.configure("token:" +  token2);
 
-        try(PulsarAdmin admin1 = spy(
+        try (PulsarAdmin admin1 = spy(
                 PulsarAdmin.builder().serviceHttpUrl(brokerServiceUrl).authentication(authToken1).build());
             PulsarAdmin admin2 = spy(
                     PulsarAdmin.builder().serviceHttpUrl(brokerServiceUrl).authentication(authToken2).build())
@@ -639,8 +657,9 @@ public class PulsarFunctionE2ESecurityTest {
             assertEquals(admin1.topics().getStats(sourceTopic).getSubscriptions().size(), 1);
 
             // create a producer that creates a topic at broker
-            try(Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(sourceTopic).create();
-            Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(sinkTopic).subscriptionName("sub").subscribe()) {
+            try (Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(sourceTopic).create();
+            Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(sinkTopic)
+                    .subscriptionName("sub").subscribe()) {
 
                 int totalMsgs = 5;
                 for (int i = 0; i < totalMsgs; i++) {
@@ -649,7 +668,8 @@ public class PulsarFunctionE2ESecurityTest {
                 }
                 retryStrategically((test) -> {
                     try {
-                        SubscriptionStats subStats = admin1.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
+                        SubscriptionStats subStats = admin1.topics().getStats(sourceTopic)
+                                .getSubscriptions().get(subscriptionName);
                         return subStats.getUnackedMessages() == 0;
                     } catch (PulsarAdminException e) {
                         return false;
@@ -664,8 +684,8 @@ public class PulsarFunctionE2ESecurityTest {
                 // validate pulsar-sink consumer has consumed all messages and delivered to Pulsar sink but unacked
                 // messages
                 // due to publish failure
-                assertNotEquals(admin1.topics().getStats(sourceTopic).getSubscriptions().values().iterator().next().getUnackedMessages(),
-                        totalMsgs);
+                assertNotEquals(admin1.topics().getStats(sourceTopic).getSubscriptions()
+                                .values().iterator().next().getUnackedMessages(), totalMsgs);
             }
 
             // test update functions
