@@ -19,16 +19,20 @@
 package org.apache.pulsar.client.impl.auth.oauth2.protocol;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.net.URL;
 import java.net.URLEncoder;
+import java.nio.charset.StandardCharsets;
 import java.util.Map;
 import java.util.TreeMap;
 import java.util.concurrent.ExecutionException;
 import java.util.stream.Collectors;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.pulsar.PulsarVersion;
 import org.apache.pulsar.common.util.ObjectMapperFactory;
 import org.asynchttpclient.AsyncHttpClient;
+import org.asynchttpclient.AsyncHttpClientConfig;
+import org.asynchttpclient.DefaultAsyncHttpClient;
+import org.asynchttpclient.DefaultAsyncHttpClientConfig;
 import org.asynchttpclient.Response;
 
 /**
@@ -36,11 +40,30 @@ import org.asynchttpclient.Response;
  */
 public class TokenClient implements ClientCredentialsExchanger {
 
+    protected static final int DEFAULT_CONNECT_TIMEOUT_IN_SECONDS = 10;
+    protected static final int DEFAULT_READ_TIMEOUT_IN_SECONDS = 30;
+
     private final URL tokenUrl;
     private final AsyncHttpClient httpClient;
 
-    public TokenClient(URL tokenUrl, AsyncHttpClient httpClient) {
-        this.httpClient = httpClient;
+    public TokenClient(URL tokenUrl) {
+        this(tokenUrl, null);
+    }
+
+    TokenClient(URL tokenUrl, AsyncHttpClient httpClient) {
+        if (httpClient == null) {
+            DefaultAsyncHttpClientConfig.Builder confBuilder = new DefaultAsyncHttpClientConfig.Builder();
+            confBuilder.setCookieStore(null);
+            confBuilder.setUseProxyProperties(true);
+            confBuilder.setFollowRedirect(true);
+            confBuilder.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_IN_SECONDS * 1000);
+            confBuilder.setReadTimeout(DEFAULT_READ_TIMEOUT_IN_SECONDS * 1000);
+            confBuilder.setUserAgent(String.format("Pulsar-Java-v%s", PulsarVersion.getVersion()));
+            AsyncHttpClientConfig config = confBuilder.build();
+            this.httpClient = new DefaultAsyncHttpClient(config);
+        } else {
+            this.httpClient = httpClient;
+        }
         this.tokenUrl = tokenUrl;
     }
 
@@ -51,7 +74,6 @@ public class TokenClient implements ClientCredentialsExchanger {
 
     /**
      * Constructing http request parameters.
-     *
      * @param req object with relevant request parameters
      * @return Generate the final request body from a map.
      */
@@ -68,19 +90,13 @@ public class TokenClient implements ClientCredentialsExchanger {
             bodyMap.put("scope", req.getScope());
         }
         return bodyMap.entrySet().stream()
-                .map(e -> {
-                    try {
-                        return URLEncoder.encode(e.getKey(), "UTF-8") + '=' + URLEncoder.encode(e.getValue(), "UTF-8");
-                    } catch (UnsupportedEncodingException e1) {
-                        throw new RuntimeException(e1);
-                    }
-                })
+                .map(e -> URLEncoder.encode(e.getKey(), StandardCharsets.UTF_8) + '='
+                        + URLEncoder.encode(e.getValue(), StandardCharsets.UTF_8))
                 .collect(Collectors.joining("&"));
     }
 
     /**
      * Performs a token exchange using client credentials.
-     *
      * @param req the client credentials request details.
      * @return a token result
      * @throws TokenExchangeException
@@ -99,26 +115,24 @@ public class TokenClient implements ClientCredentialsExchanger {
                     .get();
 
             switch (res.getStatusCode()) {
-                case 200:
-                    return ObjectMapperFactory.getMapper().reader().readValue(res.getResponseBodyAsBytes(),
-                            TokenResult.class);
+            case 200:
+                return ObjectMapperFactory.getMapper().reader().readValue(res.getResponseBodyAsBytes(),
+                        TokenResult.class);
 
-                case 400: // Bad request
-                case 401: // Unauthorized
-                    throw new TokenExchangeException(
-                            ObjectMapperFactory.getMapper().reader().readValue(res.getResponseBodyAsBytes(),
-                                    TokenError.class));
+            case 400: // Bad request
+            case 401: // Unauthorized
+                throw new TokenExchangeException(
+                        ObjectMapperFactory.getMapper().reader().readValue(res.getResponseBodyAsBytes(),
+                                TokenError.class));
 
-                default:
-                    throw new IOException(
-                            "Failed to perform HTTP request. res: " + res.getStatusCode() + " " + res.getStatusText());
+            default:
+                throw new IOException(
+                        "Failed to perform HTTP request. res: " + res.getStatusCode() + " " + res.getStatusText());
             }
 
 
+
         } catch (InterruptedException | ExecutionException e1) {
-            if (e1 instanceof InterruptedException) {
-                Thread.currentThread().interrupt();
-            }
             throw new IOException(e1);
         }
     }
