@@ -400,7 +400,7 @@ public class ConsumerConfigurationData<T> implements Serializable, Cloneable {
     @JsonIgnore
     private KeySharedPolicy keySharedPolicy;
 
-    private boolean batchIndexAckEnabled = false;
+    private boolean batchIndexAckEnabled = true;
 
     private boolean ackReceiptEnabled = false;
 
