@@ -24,7 +24,6 @@ import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertTrue;
@@ -36,13 +35,14 @@ import java.util.concurrent.CompletableFuture;
 import java.util.regex.Pattern;
 import lombok.Cleanup;
 import org.apache.commons.lang3.tuple.Pair;
-import org.apache.pulsar.client.api.Consumer;
 import org.apache.pulsar.client.impl.PatternMultiTopicsConsumerImpl.TopicsChangedListener;
 import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
+import org.apache.pulsar.common.api.proto.BaseCommand;
 import org.apache.pulsar.common.api.proto.CommandWatchTopicListSuccess;
 import org.apache.pulsar.common.api.proto.CommandWatchTopicUpdate;
 import org.apache.pulsar.common.naming.NamespaceName;
 import org.apache.pulsar.common.topics.TopicsPatternFactory;
+import org.mockito.ArgumentCaptor;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
@@ -53,7 +53,6 @@ public class TopicListWatcherTest {
     private PulsarClientImpl client;
     private CompletableFuture<TopicListWatcher> watcherFuture;
     private TopicsChangedListener listener;
-    private PatternMultiTopicsConsumerImpl<byte[]> patternConsumer;
 
     @BeforeMethod(alwaysRun = true)
     public void setup() {
@@ -75,23 +74,17 @@ public class TopicListWatcherTest {
         when(connectionPool.getConnection(any(), any(), anyInt())).thenReturn(clientCnxFuture);
 
         CompletableFuture<Void> completedFuture = CompletableFuture.completedFuture(null);
-        patternConsumer = mock(PatternMultiTopicsConsumerImpl.class);
-        when(patternConsumer.getPattern()).thenReturn(TopicsPatternFactory.create(Pattern.compile(topic)));
-        when(patternConsumer.getPartitions()).thenReturn(Collections.singletonList("persistent://tenant/ns/topic11"));
-        CompletableFuture<Consumer<byte[]>> subscribeFuture = CompletableFuture.completedFuture(patternConsumer);
-        when(patternConsumer.getSubscribeFuture()).thenReturn(subscribeFuture);
+        PatternMultiTopicsConsumerImpl patternConsumer = mock(PatternMultiTopicsConsumerImpl.class);
+        when(patternConsumer.getSubscribeFuture()).thenReturn(completedFuture);
         when(patternConsumer.recheckTopicsChange()).thenReturn(completedFuture);
         when(listener.onTopicsAdded(anyCollection())).thenReturn(completedFuture);
         when(listener.onTopicsRemoved(anyCollection())).thenReturn(completedFuture);
-        when(patternConsumer.handleWatchTopicListSuccess(any(), any(), anyInt())).thenReturn(completedFuture);
-        when(patternConsumer.supportsTopicListWatcherReconcile()).thenReturn(true);
         PatternConsumerUpdateQueue queue = new PatternConsumerUpdateQueue(patternConsumer, listener);
 
         watcherFuture = new CompletableFuture<>();
         watcher = new TopicListWatcher(queue, client,
                 TopicsPatternFactory.create(Pattern.compile(topic)), 7,
-                NamespaceName.get("tenant/ns"), patternConsumer::getLocalStateTopicsHash, watcherFuture,
-                () -> 0);
+                NamespaceName.get("tenant/ns"), null, watcherFuture, () -> {});
     }
 
     @Test
@@ -101,44 +94,34 @@ public class TopicListWatcherTest {
 
     @Test
     public void testWatcherCreatesBrokerSideObjectWhenConnected() {
-        ClientCnx clientCnx = mockClientCnx();
+        ClientCnx clientCnx = mock(ClientCnx.class);
         CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
-        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
-                .thenReturn(responseFuture);
+        ArgumentCaptor<BaseCommand> commandCaptor = ArgumentCaptor.forClass(BaseCommand.class);
+        when(clientCnx.newWatchTopicList(any(BaseCommand.class), anyLong())).thenReturn(responseFuture);
         when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
         clientCnxFuture.complete(clientCnx);
-
-        verify(clientCnx).newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any());
-
+        verify(clientCnx).newWatchTopicList(commandCaptor.capture(), anyLong());
         CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
                 .setWatcherId(7)
-                .setRequestId(0)
+                .setRequestId(commandCaptor.getValue().getWatchTopicList().getRequestId())
                 .setTopicsHash("FEED");
         success.addTopic("persistent://tenant/ns/topic11");
         responseFuture.complete(success);
         assertTrue(watcherFuture.isDone() && !watcherFuture.isCompletedExceptionally());
     }
 
-    private static ClientCnx mockClientCnx() {
-        ClientCnx clientCnx = mock(ClientCnx.class);
-        when(clientCnx.isSupportsTopicWatchers()).thenReturn(true);
-        when(clientCnx.isSupportsTopicWatcherReconcile()).thenReturn(true);
-        return clientCnx;
-    }
-
     @Test
     public void testWatcherCallsListenerOnUpdate() {
-        ClientCnx clientCnx = mockClientCnx();
+        ClientCnx clientCnx = mock(ClientCnx.class);
         CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
-        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
-                .thenReturn(responseFuture);
+        ArgumentCaptor<BaseCommand> commandCaptor = ArgumentCaptor.forClass(BaseCommand.class);
+        when(clientCnx.newWatchTopicList(any(BaseCommand.class), anyLong())).thenReturn(responseFuture);
         when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
         clientCnxFuture.complete(clientCnx);
-        verify(clientCnx).newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any());
-
+        verify(clientCnx).newWatchTopicList(commandCaptor.capture(), anyLong());
         CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
                 .setWatcherId(7)
-                .setRequestId(0)
+                .setRequestId(commandCaptor.getValue().getWatchTopicList().getRequestId())
                 .setTopicsHash("FEED");
         success.addTopic("persistent://tenant/ns/topic11");
         responseFuture.complete(success);
@@ -151,38 +134,4 @@ public class TopicListWatcherTest {
         watcher.handleCommandWatchTopicUpdate(update);
         verify(listener).onTopicsAdded(Collections.singletonList("persistent://tenant/ns/topic12"));
     }
-
-    @Test
-    public void testWatcherTriggersReconciliationOnHashMismatch() {
-        ClientCnx clientCnx = mockClientCnx();
-
-        CompletableFuture<CommandWatchTopicListSuccess> responseFuture = new CompletableFuture<>();
-        when(clientCnx.newWatchTopicList(anyLong(), anyLong(), anyString(), anyString(), any()))
-                .thenReturn(responseFuture);
-        when(clientCnx.ctx()).thenReturn(mock(ChannelHandlerContext.class));
-        clientCnxFuture.complete(clientCnx);
-
-        CommandWatchTopicListSuccess success = new CommandWatchTopicListSuccess()
-                .setWatcherId(7)
-                .setRequestId(0)
-                .setTopicsHash("FEED");
-        success.addTopic("persistent://tenant/ns/topic11");
-        responseFuture.complete(success);
-
-        // verify that the response was handled
-        verify(patternConsumer, times(1)).handleWatchTopicListSuccess(any(), any(), anyInt());
-        // sync local hash
-        when(patternConsumer.getLocalStateTopicsHash()).thenReturn("FEED");
-
-        // Send update with a mismatching hash
-        CommandWatchTopicUpdate update = new CommandWatchTopicUpdate()
-                .setTopicsHash("WRONG_HASH")
-                .setWatcherId(7)
-                .addAllNewTopics(Collections.singleton("persistent://tenant/ns/topic12"));
-
-        watcher.handleCommandWatchTopicUpdate(update);
-
-        // Verify that reconciliation was triggered again due to hash mismatch
-        verify(patternConsumer, times(1)).recheckTopicsChange();
-    }
 }
