@@ -22,6 +22,7 @@ import lombok.AllArgsConstructor;
 import lombok.Builder;
 import lombok.Data;
 import lombok.NoArgsConstructor;
+import lombok.SneakyThrows;
 import org.apache.pulsar.common.policies.data.impl.DispatchRateImpl;
 
 /**
@@ -31,7 +32,7 @@ import org.apache.pulsar.common.policies.data.impl.DispatchRateImpl;
 @Builder
 @NoArgsConstructor
 @AllArgsConstructor
-public class SubscriptionPolicies {
+public class SubscriptionPolicies implements Cloneable {
     private DispatchRateImpl dispatchRate;
 
     /**
@@ -41,4 +42,12 @@ public class SubscriptionPolicies {
     public boolean checkEmpty() {
         return dispatchRate == null;
     }
+
+    @SneakyThrows
+    @Override
+    protected SubscriptionPolicies clone() {
+        SubscriptionPolicies cloned = SubscriptionPolicies.class.cast(super.clone());
+        cloned.dispatchRate = dispatchRate != null ? dispatchRate.clone() : null;
+        return cloned;
+    }
 }
