@@ -25,4 +25,10 @@ public enum TenantOperation {
     CREATE_NAMESPACE,
     DELETE_NAMESPACE,
     LIST_NAMESPACES,
+
+    LIST_TENANTS,
+    GET_TENANT,
+    CREATE_TENANT,
+    UPDATE_TENANT,
+    DELETE_TENANT,
 }
