@@ -18,7 +18,6 @@
  */
 package org.apache.pulsar.common.semaphore;
 
-import static org.assertj.core.api.Assertions.assertThat;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNotNull;
@@ -33,15 +32,12 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.concurrent.atomic.AtomicReference;
-import java.util.function.BooleanSupplier;
 import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiter.AsyncDualMemoryLimiterPermit;
 import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiter.LimitType;
 import org.apache.pulsar.common.semaphore.AsyncSemaphore.PermitAcquireAlreadyClosedException;
 import org.apache.pulsar.common.semaphore.AsyncSemaphore.PermitAcquireCancelledException;
 import org.apache.pulsar.common.semaphore.AsyncSemaphore.PermitAcquireQueueFullException;
 import org.apache.pulsar.common.semaphore.AsyncSemaphore.PermitAcquireTimeoutException;
-import org.apache.pulsar.common.util.FutureUtil;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.Test;
 
@@ -722,25 +718,4 @@ public class AsyncDualMemoryLimiterImplTest {
             limiter.release(permit);
         }
     }
-
-    @Test(invocationCount = 100)
-    public void testUpdateHeapPermitsIncreaseWithReleasedPermits() throws Exception {
-        limiter = new AsyncDualMemoryLimiterImpl(100000, 10, 5000, 1000, 100, 5000);
-
-        BooleanSupplier cancelled = () -> false;
-        AtomicReference<CompletableFuture<Void>> future2Ref = new AtomicReference<>();
-
-        CompletableFuture<Void> future =
-                limiter.withAcquiredPermits(100, LimitType.HEAP_MEMORY, cancelled, permit -> {
-                    future2Ref.set(limiter.withUpdatedPermits(permit, 200, cancelled, updatedPermit -> {
-                                return CompletableFuture.supplyAsync(() -> null);
-                            }, FutureUtil::failedFuture));
-                    return CompletableFuture.completedFuture(null);
-                }, FutureUtil::failedFuture);
-
-        assertThat(future).succeedsWithin(1, TimeUnit.SECONDS);
-        assertThat(future2Ref.get()).succeedsWithin(1, TimeUnit.SECONDS);
-        assertThat(limiter.getLimiter(LimitType.HEAP_MEMORY).getAvailablePermits()).isEqualTo(100000);
-        assertThat(limiter.getLimiter(LimitType.HEAP_MEMORY).getAcquiredPermits()).isEqualTo(0);
-    }
 }
\ No newline at end of file
