@@ -44,7 +44,6 @@ import org.apache.pulsar.common.api.proto.BaseCommand;
 import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiter.AsyncDualMemoryLimiterPermit;
 import org.apache.pulsar.common.semaphore.AsyncDualMemoryLimiter.LimitType;
 import org.apache.pulsar.common.semaphore.AsyncSemaphore.PermitAcquireCancelledException;
-import org.apache.pulsar.common.util.FutureUtil;
 import org.awaitility.Awaitility;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeMethod;
@@ -94,7 +93,7 @@ public class AsyncDualMemoryLimiterUtilTest {
     @Test
     public void testWithPermitsFuturePermitAcquireError() throws Exception {
         CompletableFuture<AsyncDualMemoryLimiterPermit> permitFuture =
-                FutureUtil.failedFuture(new RuntimeException("Permit acquire failed"));
+                CompletableFuture.failedFuture(new RuntimeException("Permit acquire failed"));
 
         AtomicBoolean functionExecuted = new AtomicBoolean(false);
         AtomicBoolean errorHandlerExecuted = new AtomicBoolean(false);
@@ -161,7 +160,7 @@ public class AsyncDualMemoryLimiterUtilTest {
 
         CompletableFuture<String> result = AsyncDualMemoryLimiterUtil.withPermitsFuture(
                 permitFuture,
-                permit -> FutureUtil.failedFuture(new RuntimeException("Async operation failed")),
+                permit -> CompletableFuture.failedFuture(new RuntimeException("Async operation failed")),
                 throwable -> CompletableFuture.completedFuture("error"),
                 permit -> permitReleased.set(true)
         );
@@ -262,10 +261,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 limiter,
                 () -> false,
                 command,
-                throwable -> {
-                    errorHandlerCalled.set(true);
-                    return FutureUtil.failedFuture(throwable);
-                }
+                throwable -> errorHandlerCalled.set(true)
         );
 
         result.get(1, TimeUnit.SECONDS);
@@ -300,7 +296,6 @@ public class AsyncDualMemoryLimiterUtilTest {
                 throwable -> {
                     errorHandlerCalled.set(true);
                     capturedError.set(throwable);
-                    return FutureUtil.failedFuture(throwable);
                 }
         );
 
@@ -327,10 +322,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 limiter,
                 () -> false,
                 command,
-                throwable -> {
-                    errorHandlerCalled.set(true);
-                    return FutureUtil.failedFuture(throwable);
-                }
+                throwable -> errorHandlerCalled.set(true)
         );
 
         try {
@@ -358,10 +350,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 limiter,
                 () -> false,
                 command,
-                throwable -> {
-                    errorHandlerCalled.set(true);
-                    return FutureUtil.failedFuture(throwable);
-                }
+                throwable -> errorHandlerCalled.set(true)
         );
 
         try {
@@ -392,10 +381,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 limiter,
                 cancelled::get,
                 command,
-                throwable -> {
-                    errorHandlerCalled.set(true);
-                    return FutureUtil.failedFuture(throwable);
-                }
+                throwable -> errorHandlerCalled.set(true)
         );
 
         // Cancel the request
@@ -433,7 +419,6 @@ public class AsyncDualMemoryLimiterUtilTest {
                     () -> false,
                     command,
                     throwable -> {
-                        return FutureUtil.failedFuture(throwable);
                     }
             );
         }
@@ -467,10 +452,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 limiter,
                 () -> false,
                 command,
-                throwable -> {
-                    errorHandlerCalled.set(true);
-                    return FutureUtil.failedFuture(throwable);
-                }
+                throwable -> errorHandlerCalled.set(true)
         );
 
         result.get(1, TimeUnit.SECONDS);
@@ -540,10 +522,10 @@ public class AsyncDualMemoryLimiterUtilTest {
                             secondPermit -> {
                                 return CompletableFuture.completedFuture(null);
                             },
-                            throwable -> FutureUtil.failedFuture(throwable)
+                            throwable -> CompletableFuture.failedFuture(throwable)
                     );
                 },
-                throwable -> FutureUtil.failedFuture(throwable)
+                throwable -> CompletableFuture.failedFuture(throwable)
         );
         assertThat(result).succeedsWithin(Duration.ofSeconds(1));
     }
@@ -558,7 +540,7 @@ public class AsyncDualMemoryLimiterUtilTest {
                 firstPermit -> {
                     throw new RuntimeException("Exception in withAcquiredPermits");
                 },
-                throwable -> FutureUtil.failedFuture(throwable)
+                throwable -> CompletableFuture.failedFuture(throwable)
         );
         assertThat(result).failsWithin(Duration.ofSeconds(1));
         assertThat(limiter.getLimiter(LimitType.HEAP_MEMORY).getAcquiredPermits()).isEqualTo(0);
@@ -581,10 +563,10 @@ public class AsyncDualMemoryLimiterUtilTest {
                             secondPermit -> {
                                 throw new RuntimeException("Exception in withUpdatedPermits");
                             },
-                            throwable -> FutureUtil.failedFuture(throwable)
+                            throwable -> CompletableFuture.failedFuture(throwable)
                     );
                 },
-                throwable -> FutureUtil.failedFuture(throwable)
+                throwable -> CompletableFuture.failedFuture(throwable)
         );
         assertThat(result).failsWithin(Duration.ofSeconds(1));
         assertThat(limiter.getLimiter(LimitType.HEAP_MEMORY).getAcquiredPermits()).isEqualTo(0);
