@@ -23,9 +23,7 @@ import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNull;
 import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
-
 import com.google.common.collect.Lists;
-
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
@@ -40,7 +38,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.LongFunction;
-
 import lombok.Cleanup;
 import org.testng.annotations.Test;
 
@@ -248,7 +245,7 @@ public class ConcurrentLongHashMapTest {
             });
         }
 
-        assertNull(map.put(1,"v1"));
+        assertNull(map.put(1, "v1"));
         future = executor.submit(() -> {
             try {
                 barrier.await();
@@ -361,7 +358,7 @@ public class ConcurrentLongHashMapTest {
         ExecutorService executor = Executors.newCachedThreadPool();
 
         final int nThreads = 16;
-        final int N = 100_000;
+        final int num = 100_000;
         String value = "value";
 
         List<Future<?>> futures = new ArrayList<>();
@@ -371,7 +368,7 @@ public class ConcurrentLongHashMapTest {
             futures.add(executor.submit(() -> {
                 Random random = new Random();
 
-                for (int j = 0; j < N; j++) {
+                for (int j = 0; j < num; j++) {
                     long key = random.nextLong();
                     // Ensure keys are uniques
                     key -= key % (threadIdx + 1);
@@ -385,7 +382,7 @@ public class ConcurrentLongHashMapTest {
             future.get();
         }
 
-        assertEquals(map.size(), N * nThreads);
+        assertEquals(map.size(), num * nThreads);
     }
 
     @Test
@@ -396,7 +393,7 @@ public class ConcurrentLongHashMapTest {
         ExecutorService executor = Executors.newCachedThreadPool();
 
         final int nThreads = 16;
-        final int N = 100_000;
+        final int num = 100_000;
         String value = "value";
 
         List<Future<?>> futures = new ArrayList<>();
@@ -406,7 +403,7 @@ public class ConcurrentLongHashMapTest {
             futures.add(executor.submit(() -> {
                 Random random = new Random();
 
-                for (int j = 0; j < N; j++) {
+                for (int j = 0; j < num; j++) {
                     long key = random.nextLong();
                     // Ensure keys are uniques
                     key -= key % (threadIdx + 1);
@@ -420,7 +417,7 @@ public class ConcurrentLongHashMapTest {
             future.get();
         }
 
-        assertEquals(map.size(), N * nThreads);
+        assertEquals(map.size(), num * nThreads);
     }
 
     public void stressConcurrentInsertionsAndReads() throws Throwable {
@@ -486,7 +483,7 @@ public class ConcurrentLongHashMapTest {
 
         map.put(0, "zero");
 
-        assertEquals(map.keys(), Lists.newArrayList(0l));
+        assertEquals(map.keys(), Lists.newArrayList(0L));
         assertEquals(map.values(), Lists.newArrayList("zero"));
 
         map.remove(0);
@@ -500,7 +497,7 @@ public class ConcurrentLongHashMapTest {
 
         List<Long> keys = map.keys();
         keys.sort(null);
-        assertEquals(keys, Lists.newArrayList(0l, 1l, 2l));
+        assertEquals(keys, Lists.newArrayList(0L, 1L, 2L));
 
         List<String> values = map.values();
         values.sort(null);
@@ -510,7 +507,7 @@ public class ConcurrentLongHashMapTest {
 
         keys = map.keys();
         keys.sort(null);
-        assertEquals(keys, Lists.newArrayList(0l, 1l, 2l));
+        assertEquals(keys, Lists.newArrayList(0L, 1L, 2L));
 
         values = map.values();
         values.sort(null);
@@ -522,9 +519,9 @@ public class ConcurrentLongHashMapTest {
 
     @Test
     public void testHashConflictWithDeletion() {
-        final int Buckets = 16;
+        final int buckets = 16;
         ConcurrentLongHashMap<String> map = ConcurrentLongHashMap.<String>newBuilder()
-                .expectedItems(Buckets)
+                .expectedItems(buckets)
                 .concurrencyLevel(1)
                 .build();
 
@@ -532,8 +529,8 @@ public class ConcurrentLongHashMapTest {
         long key1 = 1;
         long key2 = 27;
 
-        int bucket1 = ConcurrentLongHashMap.signSafeMod(ConcurrentLongHashMap.hash(key1), Buckets);
-        int bucket2 = ConcurrentLongHashMap.signSafeMod(ConcurrentLongHashMap.hash(key2), Buckets);
+        int bucket1 = ConcurrentLongHashMap.signSafeMod(ConcurrentLongHashMap.hash(key1), buckets);
+        int bucket2 = ConcurrentLongHashMap.signSafeMod(ConcurrentLongHashMap.hash(key2), buckets);
         assertEquals(bucket1, bucket2);
 
         assertNull(map.put(key1, "value-1"));
