@@ -53,7 +53,8 @@ public class ClusterServiceCoordinatorTest {
 
         this.leaderService = mock(LeaderService.class);
         this.checkIsStillLeader = () -> leaderService.isLeader();
-        this.coordinator = new ClusterServiceCoordinator("test-coordinator", leaderService, checkIsStillLeader, mockExecutor);
+        this.coordinator = new ClusterServiceCoordinator("test-coordinator", leaderService,
+                checkIsStillLeader, mockExecutor);
     }
 
 
