@@ -60,6 +60,8 @@ import org.testng.annotations.Test;
 @Slf4j
 public class FunctionAssignmentTailerTest {
 
+    private static final String CLUSTER_NAME = "test-cluster";
+
     @Test(timeOut = 10000)
     public void testErrorNotifier() throws Exception {
         WorkerConfig workerConfig = new WorkerConfig();
@@ -71,6 +73,7 @@ public class FunctionAssignmentTailerTest {
         workerConfig.setPulsarServiceUrl("pulsar://localhost:6650");
         workerConfig.setStateStorageServiceUrl("foo");
         workerConfig.setFunctionAssignmentTopicName("assignments");
+        workerConfig.setPulsarFunctionsCluster(CLUSTER_NAME);
 
         Function.FunctionMetaData function1 = Function.FunctionMetaData.newBuilder().setFunctionDetails(
                 Function.FunctionDetails.newBuilder()
@@ -183,6 +186,7 @@ public class FunctionAssignmentTailerTest {
         workerConfig.setPulsarServiceUrl("pulsar://localhost:6650");
         workerConfig.setStateStorageServiceUrl("foo");
         workerConfig.setFunctionAssignmentTopicName("assignments");
+        workerConfig.setPulsarFunctionsCluster(CLUSTER_NAME);
 
         Function.FunctionMetaData function1 = Function.FunctionMetaData.newBuilder().setFunctionDetails(
                 Function.FunctionDetails.newBuilder()
@@ -307,6 +311,7 @@ public class FunctionAssignmentTailerTest {
         workerConfig.setPulsarServiceUrl("pulsar://localhost:6650");
         workerConfig.setStateStorageServiceUrl("foo");
         workerConfig.setFunctionAssignmentTopicName("assignments");
+        workerConfig.setPulsarFunctionsCluster(CLUSTER_NAME);
 
         Function.FunctionMetaData function1 = Function.FunctionMetaData.newBuilder().setFunctionDetails(
                 Function.FunctionDetails.newBuilder()
