@@ -30,7 +30,7 @@ import org.apache.pulsar.io.kafka.connect.PulsarKafkaWorkerConfig;
 @Slf4j
 public abstract class DebeziumSource extends KafkaConnectSource {
     private static final String DEFAULT_CONVERTER = "org.apache.kafka.connect.json.JsonConverter";
-    private static final String DEFAULT_HISTORY = "org.apache.pulsar.io.debezium.PulsarDatabaseHistory";
+    private static final String DEFAULT_HISTORY = "org.apache.pulsar.io.debezium.PulsarSchemaHistory";
     private static final String DEFAULT_OFFSET_TOPIC = "debezium-offset-topic";
     private static final String DEFAULT_HISTORY_TOPIC = "debezium-history-topic";
 
@@ -76,6 +76,8 @@ public abstract class DebeziumSource extends KafkaConnectSource {
 
     public abstract void setDbConnectorTask(Map<String, Object> config) throws Exception;
 
+    public abstract void setDbConnectorClass(Map<String, Object> config) throws Exception;
+
     @Override
     public void open(Map<String, Object> config, SourceContext sourceContext) throws Exception {
         setDbConnectorTask(config);
@@ -87,28 +89,28 @@ public abstract class DebeziumSource extends KafkaConnectSource {
         // value.converter
         setConfigIfNull(config, PulsarKafkaWorkerConfig.VALUE_CONVERTER_CLASS_CONFIG, DEFAULT_CONVERTER);
 
-        // database.history : implementation class for database history.
-        setConfigIfNull(config, HistorizedRelationalDatabaseConnectorConfig.DATABASE_HISTORY.name(), DEFAULT_HISTORY);
+        // schema.history : implementation class for schema history.
+        setConfigIfNull(config, HistorizedRelationalDatabaseConnectorConfig.SCHEMA_HISTORY.name(), DEFAULT_HISTORY);
 
-        // database.history.pulsar.service.url
-        String pulsarUrl = (String) config.get(PulsarDatabaseHistory.SERVICE_URL.name());
+        // schema.history.internal.pulsar.service.url
+        String pulsarUrl = (String) config.get(PulsarSchemaHistory.SERVICE_URL.name());
 
         String topicNamespace = topicNamespace(sourceContext);
         // topic.namespace
         setConfigIfNull(config, PulsarKafkaWorkerConfig.TOPIC_NAMESPACE_CONFIG, topicNamespace);
 
         String sourceName = sourceContext.getSourceName();
-        // database.history.pulsar.topic: history topic name
-        setConfigIfNull(config, PulsarDatabaseHistory.TOPIC.name(),
+        // schema.history.internal.pulsar.topic: history topic name
+        setConfigIfNull(config, PulsarSchemaHistory.TOPIC.name(),
             topicNamespace + "/" + sourceName + "-" + DEFAULT_HISTORY_TOPIC);
         // offset.storage.topic: offset topic name
         setConfigIfNull(config, PulsarKafkaWorkerConfig.OFFSET_STORAGE_TOPIC_CONFIG,
             topicNamespace + "/" + sourceName + "-" + DEFAULT_OFFSET_TOPIC);
 
-        // pass pulsar.client.builder if database.history.pulsar.service.url is not provided
+        // pass pulsar.client.builder if schema.history.internal.pulsar.service.url is not provided
         if (StringUtils.isEmpty(pulsarUrl)) {
             String pulsarClientBuilder = SerDeUtils.serialize(sourceContext.getPulsarClientBuilder());
-            config.put(PulsarDatabaseHistory.CLIENT_BUILDER.name(), pulsarClientBuilder);
+            config.put(PulsarSchemaHistory.CLIENT_BUILDER.name(), pulsarClientBuilder);
         }
 
         super.open(config, sourceContext);
