@@ -21,6 +21,7 @@ package org.apache.pulsar.io.http;
 import static com.github.tomakehurst.wiremock.client.WireMock.aResponse;
 import static com.github.tomakehurst.wiremock.client.WireMock.configureFor;
 import static com.github.tomakehurst.wiremock.client.WireMock.equalTo;
+import static com.github.tomakehurst.wiremock.client.WireMock.equalToJson;
 import static com.github.tomakehurst.wiremock.client.WireMock.post;
 import static com.github.tomakehurst.wiremock.client.WireMock.postRequestedFor;
 import static com.github.tomakehurst.wiremock.client.WireMock.stubFor;
@@ -429,7 +430,7 @@ public class HttpSinkTest {
         httpSink.write(record);
 
         verify(postRequestedFor(urlEqualTo("/"))
-            .withRequestBody(equalTo(responseBody))
+            .withRequestBody(equalToJson(responseBody))
             .withHeader("Content-Type", equalTo("application/json"))
             .withHeader("header-name", equalTo("header-value"))
             .withHeader("PulsarTopic", equalTo("test-topic"))
