@@ -368,18 +368,17 @@ public class LookupProxyHandler {
         listSizeHolder.getSizeAsync().thenAccept(initialSize -> {
             maxTopicListInFlightLimiter.withAcquiredPermits(initialSize,
                     AsyncDualMemoryLimiter.LimitType.HEAP_MEMORY, isPermitRequestCancelled, initialPermits -> {
-                        return clientCnx.newGetTopicsOfNamespace(command, requestId).handle((r, t) -> {
+                        return clientCnx.newGetTopicsOfNamespace(command, requestId).whenComplete((r, t) -> {
                             if (t != null) {
                                 log.warn("[{}] Failed to get TopicsOfNamespace {}: {}", clientAddress, namespaceName,
                                         t.getMessage());
                                 listSizeHolder.resetIfInitializing();
                                 writeAndFlush(Commands.newError(clientRequestId, getServerError(t), t.getMessage()));
-                                return CompletableFuture.completedFuture(null);
                             } else {
                                 long actualSize = TopicListMemoryLimiter.estimateTopicListSize(
                                         r.getNonPartitionedOrPartitionTopics());
                                 listSizeHolder.updateSize(actualSize);
-                                return maxTopicListInFlightLimiter.withUpdatedPermits(initialPermits, actualSize,
+                                maxTopicListInFlightLimiter.withUpdatedPermits(initialPermits, actualSize,
                                         isPermitRequestCancelled, permits -> {
                                             return handleWritingGetTopicsResponse(clientRequestId, r,
                                                     isPermitRequestCancelled);
@@ -393,7 +392,7 @@ public class LookupProxyHandler {
                                             return CompletableFuture.completedFuture(null);
                                         });
                             }
-                        });
+                        }).thenApply(__ -> null);
                     }, t -> {
                         log.warn("[{}] Failed to acquire initial heap memory permits for GetTopicsOfNamespace: {}",
                                 clientAddress, t.getMessage());
@@ -421,7 +420,6 @@ public class LookupProxyHandler {
                             clientAddress, t.getMessage());
                     writeAndFlush(Commands.newError(clientRequestId, ServerError.TooManyRequests,
                             "Failed due to direct memory limit exceeded"));
-                    return CompletableFuture.completedFuture(null);
                 });
     }
 
