@@ -47,6 +47,7 @@ import org.apache.pulsar.broker.web.plugin.servlet.AdditionalServlets;
 import org.apache.pulsar.client.api.Authentication;
 import org.apache.pulsar.client.api.AuthenticationFactory;
 import org.apache.pulsar.common.configuration.PulsarConfigurationLoader;
+import org.apache.pulsar.common.util.ObjectMapperFactory;
 import org.apache.pulsar.metadata.impl.ZKMetadataStore;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.servlet.ServletHolder;
@@ -66,6 +67,7 @@ public class ProxyAdditionalServletTest extends MockedPulsarServiceBaseTest {
     private WebServer proxyWebServer;
     private ProxyConfiguration proxyConfig = new ProxyConfiguration();
     private Authentication proxyClientAuthentication;
+    private Map<String, String> responseHeaders = new HashMap<>();
 
     @Override
     @BeforeClass
@@ -80,6 +82,9 @@ public class ProxyAdditionalServletTest extends MockedPulsarServiceBaseTest {
         // enable full parsing feature
         proxyConfig.setProxyLogLevel(Optional.of(2));
         proxyConfig.setClusterName(configClusterName);
+        responseHeaders.put("header1", "value1");
+        proxyConfig.setProxyHttpResponseHeadersJson(
+                ObjectMapperFactory.getMapper().writer().writeValueAsString(responseHeaders));
 
         // this is for nar package test
 //        addServletNar();
@@ -199,11 +204,15 @@ public class ProxyAdditionalServletTest extends MockedPulsarServiceBaseTest {
         int httpPort = proxyWebServer.getListenPortHTTP().get();
         log.info("proxy service httpPort {}", httpPort);
         String paramValue = "value - " + RandomUtils.nextInt();
-        String response = httpGet("http://localhost:" + httpPort + BASE_PATH + "?" + QUERY_PARAM + "=" + paramValue);
+        final Map<String, String> headers = new HashMap<>();
+        String response = httpGet("http://localhost:" + httpPort + BASE_PATH + "?" + QUERY_PARAM + "=" + paramValue,
+                headers);
         Assert.assertEquals(response, paramValue);
+        String headerKey = "header1";
+        Assert.assertEquals(headers.get(headerKey), responseHeaders.get(headerKey));
     }
 
-    String httpGet(String url) throws IOException {
+    String httpGet(String url, Map<String, String> headers) throws IOException {
         OkHttpClient client = new OkHttpClient();
         okhttp3.Request request = new okhttp3.Request.Builder()
                 .get()
@@ -211,6 +220,9 @@ public class ProxyAdditionalServletTest extends MockedPulsarServiceBaseTest {
                 .build();
 
         try (Response response = client.newCall(request).execute()) {
+            response.headers().forEach(pair -> {
+                headers.put(pair.getFirst(), pair.getSecond());
+            });
             return response.body().string();
         }
     }
