@@ -38,8 +38,8 @@ import org.apache.bookkeeper.mledger.ManagedLedgerException;
 import org.apache.bookkeeper.mledger.ManagedLedgerException.ManagedLedgerAlreadyClosedException;
 import org.apache.bookkeeper.mledger.ManagedLedgerFactory;
 import org.apache.bookkeeper.mledger.Position;
+import org.apache.bookkeeper.mledger.PositionFactory;
 import org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl;
-import org.apache.bookkeeper.mledger.impl.PositionImpl;
 import org.apache.pulsar.common.allocator.PulsarByteBufAllocator;
 import org.apache.pulsar.common.api.proto.CommandSubscribe;
 import org.apache.pulsar.common.naming.NamespaceName;
@@ -156,7 +156,7 @@ public class MLTransactionLogImpl implements TransactionLog {
 
     private void readAsync(int numberOfEntriesToRead,
                            AsyncCallbacks.ReadEntriesCallback readEntriesCallback) {
-        cursor.asyncReadEntries(numberOfEntriesToRead, readEntriesCallback, System.nanoTime(), PositionImpl.LATEST);
+        cursor.asyncReadEntries(numberOfEntriesToRead, readEntriesCallback, System.nanoTime(), PositionFactory.LATEST);
     }
 
     @Override
@@ -264,7 +264,7 @@ public class MLTransactionLogImpl implements TransactionLog {
                              * 3. Build batched position and handle valid data.
                              */
                             long[] ackSetAlreadyAck = cursor.getDeletedBatchIndexesAsLongArray(
-                                    PositionImpl.get(entry.getLedgerId(), entry.getEntryId()));
+                                    PositionFactory.create(entry.getLedgerId(), entry.getEntryId()));
                             BitSetRecyclable bitSetAlreadyAck = null;
                             if (ackSetAlreadyAck != null){
                                 bitSetAlreadyAck = BitSetRecyclable.valueOf(ackSetAlreadyAck);
