@@ -18,6 +18,13 @@
  */
 package org.apache.pulsar.tests.integration.io;
 
+import static org.apache.pulsar.tests.integration.functions.utils.CommandGenerator.JAVAJAR;
+import static org.testng.Assert.assertEquals;
+import static org.testng.Assert.assertTrue;
+import static org.testng.Assert.fail;
+import java.util.Arrays;
+import java.util.List;
+import java.util.stream.Collectors;
 import lombok.Builder;
 import lombok.Cleanup;
 import lombok.Data;
@@ -39,17 +46,8 @@ import org.apache.pulsar.tests.integration.suites.PulsarStandaloneTestSuite;
 import org.apache.pulsar.tests.integration.topologies.PulsarCluster;
 import org.testng.annotations.Test;
 
-import java.util.Arrays;
-import java.util.List;
-import java.util.stream.Collectors;
-
-import static org.apache.pulsar.tests.integration.functions.utils.CommandGenerator.JAVAJAR;
-import static org.testng.Assert.assertEquals;
-import static org.testng.Assert.assertTrue;
-import static org.testng.Assert.fail;
-
 /**
- * Test behaviour of simple sinks
+ * Test behaviour of simple sinks.
  */
 @Slf4j
 public class PulsarGenericObjectSinkTest extends PulsarStandaloneTestSuite {
@@ -102,14 +100,20 @@ public class PulsarGenericObjectSinkTest extends PulsarStandaloneTestSuite {
         // we create one sink that listens on multiple topics, send the records and verify the sink
         List<SinkSpec<?>> specs = Arrays.asList(
                 new SinkSpec<>("test-kv-sink-input-string-" + randomName(8), Schema.STRING, "foo"),
-                new SinkSpec<>("test-kv-sink-input-avro-" + randomName(8), Schema.AVRO(Pojo.class), Pojo.builder().field1("a").field2(2).build()),
-                new SinkSpec<>("test-kv-sink-input-json-" + randomName(8), Schema.JSON(Pojo.class), Pojo.builder().field1("a").field2(2).build()),
+                new SinkSpec<>("test-kv-sink-input-avro-" + randomName(8), Schema.AVRO(Pojo.class),
+                        Pojo.builder().field1("a").field2(2).build()),
+                new SinkSpec<>("test-kv-sink-input-json-" + randomName(8), Schema.JSON(Pojo.class),
+                        Pojo.builder().field1("a").field2(2).build()),
                 new SinkSpec<>("test-kv-sink-input-kv-string-int-" + randomName(8),
                         Schema.KeyValue(Schema.STRING, Schema.INT32), new KeyValue<>("foo", 123)),
                 new SinkSpec<>("test-kv-sink-input-kv-avro-json-inl-" + randomName(8),
-                        Schema.KeyValue(Schema.AVRO(PojoKey.class), Schema.JSON(Pojo.class), KeyValueEncodingType.INLINE), new KeyValue<>(PojoKey.builder().field1("a").build(), Pojo.builder().field1("a").field2(2).build())),
+                        Schema.KeyValue(Schema.AVRO(PojoKey.class), Schema.JSON(Pojo.class),
+                                KeyValueEncodingType.INLINE), new KeyValue<>(PojoKey.builder().field1("a").build(),
+                        Pojo.builder().field1("a").field2(2).build())),
                 new SinkSpec("test-kv-sink-input-kv-avro-json-sep-" + randomName(8),
-                        Schema.KeyValue(Schema.AVRO(PojoKey.class), Schema.JSON(Pojo.class), KeyValueEncodingType.SEPARATED), new KeyValue<>(PojoKey.builder().field1("a").build(), Pojo.builder().field1("a").field2(2).build()))
+                        Schema.KeyValue(Schema.AVRO(PojoKey.class), Schema.JSON(Pojo.class),
+                                KeyValueEncodingType.SEPARATED), new KeyValue<>(PojoKey.builder().field1("a").build(),
+                        Pojo.builder().field1("a").field2(2).build()))
         );
 
         final int numRecordsPerTopic = 2;
@@ -119,7 +123,8 @@ public class PulsarGenericObjectSinkTest extends PulsarStandaloneTestSuite {
                 .stream()
                 .map(SinkSpec::getOutputTopicName)
                 .collect(Collectors.joining(","));
-        submitSinkConnector(sinkName, topicNames, "org.apache.pulsar.tests.integration.io.TestGenericObjectSink", JAVAJAR);
+        submitSinkConnector(sinkName, topicNames, "org.apache.pulsar.tests.integration.io.TestGenericObjectSink",
+                JAVAJAR);
         // get sink info
         getSinkInfoSuccess(sinkName);
         getSinkStatus(sinkName);
@@ -174,7 +179,8 @@ public class PulsarGenericObjectSinkTest extends PulsarStandaloneTestSuite {
                     .property("expectedType", spec.schema.getSchemaInfo().getType().toString())
                     .property("recordNumber", i + "")
                     .send();
-            log.info("sent message {} {}  with ID {}", spec.testValue, spec.schema.getSchemaInfo().getType().toString(), messageId);
+            log.info("sent message {} {}  with ID {}", spec.testValue,
+                    spec.schema.getSchemaInfo().getType().toString(), messageId);
         }
     }
 
@@ -194,7 +200,8 @@ public class PulsarGenericObjectSinkTest extends PulsarStandaloneTestSuite {
         String sinkName = "genericobject-sink";
         String topicName = "test-genericobject-sink-schema-change";
 
-        submitSinkConnector(sinkName, topicName, "org.apache.pulsar.tests.integration.io.TestGenericObjectSink", JAVAJAR);
+        submitSinkConnector(sinkName, topicName, "org.apache.pulsar.tests.integration.io.TestGenericObjectSink",
+                JAVAJAR);
         // get sink info
         getSinkInfoSuccess(sinkName);
         getSinkStatus(sinkName);
